@@ -197,7 +197,7 @@ class DeviceServiceHttpRequestHandler(HttpRequestHandler):
             request.get_argument(
                 'mac_address',
                 data_type=HttpRequest.ArgumentDataType.macaddr,
-                is_required=True
+                is_required=False
             ),
             strict=False
         )
@@ -211,7 +211,7 @@ class DeviceServiceHttpRequestHandler(HttpRequestHandler):
         serial_number = request.get_argument(
             'serial_number',
             data_type=HttpRequest.ArgumentDataType.string,
-            is_required=True
+            is_required=False
         )
 
         return DeviceService().shake_hands(
